# PyGTK Shell 1.90.1 Installation

Felix Rabe
`<public@felixrabe.textdriven.com>`

## Dependencies

Older versions may work, but I might not be able to help out if they don't.

- Python 2.5

- GTK+ 2.10

- PyGTK 2.10

The best way to install those dependencies is to use your operating system's package management facilities. For Microsoft Windows, go to the PyGTK website and look for an all-in-one installer package. I don't know about Mac OS X personally.

## Getting the PyGTK Shell Source Code

You have two options to get PyGTK Shell:

### From the source code package (most users)

Get the latest source code package and extract it into a directory of your choice.

### From the Git repository (developers)

There is also a Git repository you can clone / pull from:

    $ git clone http://felixrabe.textdriven.com/pygtk-shell/pygtk-shell.git

This repository includes the history since the preparation of the release of PyGTK Shell 1.90.0.

## Installation

Make sure the PyGTKShell package is visible from Python, for example:

    # ln -s <pygtk-shell>/PyGTKShell /usr/local/lib/python2.5/site-packages/PyGTKShell

Now you should be able to use the PyGTKShell modules. Continue by reading the tutorial.